:mod:`cursor` -- Cursor class to iterate over MongoLab query results
--------------------------------------------------------------------

.. automodule:: pymongolab.cursor
    :synopsis: Cursor class to iterate over MongoLab query results
    :members:
    :undoc-members:
    :show-inheritance:
